/*
 * Copyright 2015, Yahoo Inc.
 * Copyrights licensed under the New BSD License.
 * See the accompanying LICENSE file for terms.
 */
var DEFAULT_CONSTRUCTORS = [
    Intl.DateTimeFormat,
    Intl.NumberFormat,
    Intl.PluralRules
];
export default function areIntlLocalesSupported(locales, constructorsToCheck) {
    if (constructorsToCheck === void 0) { constructorsToCheck = DEFAULT_CONSTRUCTORS; }
    if (typeof Intl === 'undefined') {
        return false;
    }
    if (!locales) {
        throw new Error('locales must be supplied.');
    }
    if (!Array.isArray(locales)) {
        locales = [locales];
    }
    var intlConstructors = constructorsToCheck.filter(Boolean);
    if (intlConstructors.length === 0) {
        return false;
    }
    return intlConstructors.every(function (intlConstructor) {
        return intlConstructor.supportedLocalesOf(locales).length === locales.length;
    });
}
